@@ -389,13 +389,18 @@ class SVMONReport:
        headers['Content-Type'] = 'application/json'
        headers['Authorization'] = 'Bearer ' + apiToken
 
-       cert = os.environ.get('CERTIFICATE_PATH', cwd + "/chain_TERENA_SSL_CA_3.pem")
+       cert = os.environ.get('CERTIFICATE_PATH', cwd + "/svmon_eudat_eu.cer")
        if(not len(self.service_names)):
            print('No services available, sending report failed')
            exit(1)
 
        postErrors = 0
        for i in range(len(self.service_names)):
+           if(self.tags[i] == services.get_empty_version()):
+               if(enableDebug):
+                  print('No version detected for '+ self.service_type +' skipping report...')
+               continue
+
            res = {}
            res['siteName']=self.site
            res['hostNameId']=self.host
