@@ -76,7 +76,8 @@ def get_service_tag(service_type,configs=None):
     elif service_type == "gitlab":
         tmp = get_package_version("gitlab", 0 , 1)
         if(enableDebug):
-            print('get_service_tag for gitlab result: ', tmp)
+            versionToString = tmp.decode('utf-8')
+            print('get_service_tag for gitlab result: ', versionToString)
         tmp = to_bytes(tmp)
         if tmp == None or tmp == '' or tmp.find('Failed'.encode('utf-8')) >-1:
             print("no gitlab version can be resolved")
@@ -86,22 +87,37 @@ def get_service_tag(service_type,configs=None):
 
     elif service_type == "b2safe":
         tmp=get_package_version("b2safe")
-        if(enableDebug):
-            print('get_service_tag for b2safe result: ', tmp)
-        if tmp == "":
-            print("no b2safe version can be resolved")
-            exit(1)
-        tags.append(tmp)
+
+        try:
+            versionToString = tmp.decode('utf-8')
+        except (UnicodeDecodeError, AttributeError):
+            versionToString = tmp
+            pass
+
+        if versionToString == "":
+            if(enableDebug):
+                print("no b2safe version can be resolved")
+            tags.append(get_empty_version())
+        else:
+            tags.append(versionToString)
 
         tmp=get_package_version("irods-server")
+        try:
+            versionToString = tmp.decode('utf-8')
+        except (UnicodeDecodeError, AttributeError):
+            versionToString = tmp
+            pass
         if(enableDebug):
-            print('get_service_tag for irods-server result: '+ tmp)
-        if tmp != None and tmp != '' and tmp.find('Failed'.encode('utf-8')) == -1:
-            tags.append(tmp)
+            print('get_service_tag for irods-server result: '+ versionToString)
+
+        if versionToString != None and versionToString != '':
+            tags.append(versionToString)
             return tags
+
         tmp=get_package_version("irods-icat")
         if(enableDebug):
-            print('get_service_tag for irods-icat result: '+tmp)
+            versionToString = tmp.decode('utf-8')
+            print('get_service_tag for irods-icat result: '+versionToString)
         tmp = to_bytes(tmp)
         if tmp != None and tmp != '' and tmp.find('Failed'.encode('utf-8')) == -1:
             tags.append(tmp)
@@ -135,7 +151,6 @@ def get_service_tag(service_type,configs=None):
 def get_package_version(software,start=0,end=0):
     config = remoteConfig.RemoteConfig().getConfig()
     enableDebug = config["DEBUG_MODE"]
-    print('Get_package_version for software: '+software)
     if(enableDebug):
         print('Get_package_version for software: '+software)
 
@@ -222,11 +237,11 @@ def extractVersionFromCommandResult(software,unparsedVersion, start,end):
 
     if len(parsedVersion) > end:
         if start == end:
-            return ltmp[start]
+            return parsedVersion[start]
         elif start < end:
             res=""
             for i in range(start,end+1):
-                res=res+ltmp[i]
+                res=res+parsedVersion[i]
             return res
         else:
             print('Failed, the start index should be smaller than end index for a correct rpm package resolver')
@@ -244,6 +259,9 @@ def get():
     tags=get_service_tag("svmon_client")
     return tags[0]
 
+def get_empty_version():
+    return 'N/A'
+
 def get_handle_server(handle_server_path):
     tmp = subprocess.Popen(handle_server_path, shell=True, stdout = subprocess.PIPE)
     tmp = tmp.communicate()
